# -*- coding: utf-8 -*-
# @Time    : 2020-07-16 14:44
# @Author  : xzr
# @File    : widgets
# @Software: PyCharm
# @Contact : xzregg@gmail.com
# @Desc    : 

from django.utils.translation import gettext_lazy as _

